@@ -112,14 +112,18 @@ face_tool_button_reposition_window (GtkhtmlFaceToolButton *button)
 	gint monitor_num;
 	gint x, y, width, height;
 
-	window = GTK_WIDGET (button)->window;
 	screen = gtk_widget_get_screen (GTK_WIDGET (button));
+	window = gtk_widget_get_window (GTK_WIDGET (button));
 	monitor_num = gdk_screen_get_monitor_at_window (screen, window);
 	gdk_screen_get_monitor_geometry (screen, monitor_num, &monitor);
 
 	gdk_window_get_origin (window, &x, &y);
 
+#if GTK_CHECK_VERSION(2,19,7)
+	if (!gtk_widget_get_has_window (GTK_WIDGET (button))) {
+#else
 	if (GTK_WIDGET_NO_WINDOW (button)) {
+#endif
 		x += GTK_WIDGET (button)->allocation.x;
 		y += GTK_WIDGET (button)->allocation.y;
 	}
@@ -324,7 +328,11 @@ face_tool_button_popup (GtkhtmlFaceToolButton *button)
 	GdkWindow *window;
 	GdkGrabStatus status;
 
+#if GTK_CHECK_VERSION(2,19,7)
+	if (!gtk_widget_get_realized (GTK_WIDGET (button)))
+#else
 	if (!GTK_WIDGET_REALIZED (button))
+#endif
 		return;
 
 	if (button->priv->popup_shown)
@@ -342,7 +350,7 @@ face_tool_button_popup (GtkhtmlFaceToolButton *button)
 	gtk_toggle_tool_button_set_active (tool_button, TRUE);
 
 	/* Try to grab the pointer and keyboard. */
-	window = button->priv->window->window;
+	window = gtk_widget_get_window (button->priv->window);
 	status = gdk_pointer_grab (
 		window, TRUE,
 		GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK |
@@ -366,7 +374,11 @@ face_tool_button_popdown (GtkhtmlFaceToolButton *button)
 {
 	GtkToggleToolButton *tool_button;
 
+#if GTK_CHECK_VERSION(2,19,7)
+	if (!gtk_widget_get_realized (GTK_WIDGET (button)))
+#else
 	if (!GTK_WIDGET_REALIZED (button))
+#endif
 		return;
 
 	if (!button->priv->popup_shown)
@@ -522,7 +534,7 @@ face_tool_button_init (GtkhtmlFaceToolButton *button)
 	gtk_window_set_resizable (GTK_WINDOW (window), FALSE);
 	gtk_window_set_type_hint (
 		GTK_WINDOW (window), GDK_WINDOW_TYPE_HINT_COMBO);
-	if (GTK_WIDGET_TOPLEVEL (toplevel)) {
+	if (gtk_widget_is_toplevel (toplevel)) {
 		gtk_window_group_add_window (
 			gtk_window_get_group (GTK_WINDOW (toplevel)),
 			GTK_WINDOW (window));
