@@ -78,7 +78,7 @@ draw (HTMLObject *o,
 		new_x = o->x + tx;
 		new_y = o->y + ty - o->ascent;
 
-		if (element->widget->parent) {
+		if (gtk_widget_get_parent (element->widget)) {
 			if (new_x != element->abs_x || new_y != element->abs_y) {
 				d (printf ("element: %p moveto: %d,%d shown: %d\n", element, new_x, new_y, GTK_WIDGET_VISIBLE (element->widget)));
 				gtk_layout_move (GTK_LAYOUT(element->parent), element->widget, new_x, new_y);
@@ -89,7 +89,7 @@ draw (HTMLObject *o,
 		element->abs_x = new_x;
 		element->abs_y = new_y;
 
-		if (!element->widget->parent) {
+		if (!gtk_widget_get_parent (element->widget)) {
 			d (printf ("element: %p put: %d,%d shown: %d\n", element, new_x, new_y, GTK_WIDGET_VISIBLE (element->widget)));
 			gtk_layout_put (GTK_LAYOUT(element->parent), element->widget, new_x, new_y);
 		}
@@ -107,18 +107,21 @@ destroy (HTMLObject *o)
 	d (printf ("destroy embedded %p\n", o));
 	element = HTML_EMBEDDED (o);
 
-	if(element->name)
+	if (element->name)
 		g_free(element->name);
-	if(element->value)
+	if (element->value)
 		g_free(element->value);
-	if(element->widget) {
+	if (element->widget) {
+		GtkWidget *parent;
+
 		gtk_widget_hide (element->widget);
+		parent = gtk_widget_get_parent (element->widget);
 		g_signal_handlers_disconnect_matched (element->widget, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, element);
 		if (element->changed_id > 0)
 			g_signal_handler_disconnect (element->widget, element->changed_id);
 		g_object_set_data (G_OBJECT (element->widget), "embeddedelement", NULL);
-		if (element->widget->parent && element->parent) {
-			g_assert (element->widget->parent == element->parent);
+		if (parent && element->parent) {
+			g_assert (parent == element->parent);
 			gtk_container_remove (GTK_CONTAINER (element->parent), element->widget);
 		} else {
 			g_object_ref_sink (element->widget);
@@ -146,7 +149,11 @@ calc_min_width (HTMLObject *self,
 
 	widget = HTML_EMBEDDED (self)->widget;
 
+#if GTK_CHECK_VERSION(2,19,7)
+	if (widget == NULL || !gtk_widget_get_visible (widget))
+#else
 	if (widget == NULL || !GTK_WIDGET_VISIBLE (widget))
+#endif
 		return 0;
 
 	requisition.width = requisition.height = 0;
@@ -200,7 +207,7 @@ accepts_cursor (HTMLObject *o)
 }
 
 static gchar *
-encode (HTMLEmbedded *e, const gchar* codepage)
+encode (HTMLEmbedded *e, const gchar * codepage)
 {
 	return g_strdup ("");
 }
@@ -212,7 +219,7 @@ html_embedded_reset (HTMLEmbedded *e)
 }
 
 gchar *
-html_embedded_encode (HTMLEmbedded *e, const gchar* codepage)
+html_embedded_encode (HTMLEmbedded *e, const gchar * codepage)
 {
 	return HTML_EMBEDDED_CLASS (HTML_OBJECT (e)->klass)->encode (e, codepage);
 }
@@ -232,23 +239,23 @@ html_embedded_set_form (HTMLEmbedded *e, HTMLForm *form)
 gchar *
 html_embedded_encode_string (const gchar *before, const gchar *codepage)
 {
-	    const gchar* str = before;
-	    static gchar *safe = "$-._!*(),"; /* RFC 1738 */
+	    const gchar * str = before;
+	    static const gchar *safe = "$-._!*(),"; /* RFC 1738 */
         unsigned pos = 0;
         GString *encoded = g_string_new ("");
         gchar buffer[5], *ptr;
 		guchar c;
-		
+
 	    GIConv iconv_cd = generate_iconv_to (codepage);
-	    if( is_valid_g_iconv (iconv_cd))
+	    if ( is_valid_g_iconv (iconv_cd))
 	    {
-	    	str= convert_text_encoding(iconv_cd, before);
-	    	g_iconv_close(iconv_cd);
+		str= convert_text_encoding(iconv_cd, before);
+		g_iconv_close(iconv_cd);
 	    }
 
-        while ( pos < strlen(str) ) {
+        while (pos < strlen(str)) {
 
-		c = (unsigned char) str[pos];
+		c = (guchar) str[pos];
 
 		if ( (( c >= 'A') && ( c <= 'Z')) ||
 		     (( c >= 'a') && ( c <= 'z')) ||
@@ -258,17 +265,17 @@ html_embedded_encode_string (const gchar *before, const gchar *codepage)
 			{
 				encoded = g_string_append_c (encoded, c);
 			}
-		else if ( c == ' ' )
+		else if (c == ' ')
 			{
 				encoded = g_string_append_c (encoded, '+');
 			}
-		else if ( c == '\n' )
+		else if (c == '\n')
 			{
 				encoded = g_string_append (encoded, "%0D%0A");
 			}
-		else if ( c != '\r' )
+		else if (c != '\r')
 			{
-				sprintf( buffer, "%%%02X", (int)c );
+				sprintf( buffer, "%%%02X", (gint)c );
 				encoded = g_string_append (encoded, buffer);
 				}
 		pos++;
@@ -318,8 +325,8 @@ void
 html_embedded_init (HTMLEmbedded *element,
 		   HTMLEmbeddedClass *klass,
 		   GtkWidget *parent,
-		   gchar *name,
-		   gchar *value)
+		   const gchar *name,
+		   const gchar *value)
 {
 	HTMLObject *object;
 
@@ -345,7 +352,6 @@ html_embedded_init (HTMLEmbedded *element,
 	element->changed_id = 0;
 }
 
-
 static gboolean
 html_embedded_grab_cursor(GtkWidget *eb, GdkEvent *event)
 {
@@ -390,6 +396,10 @@ html_embedded_new_widget (GtkWidget *parent, GtkHTMLEmbedded *eb, HTMLEngine *en
 static void
 html_embedded_allocate (GtkWidget *w, GtkAllocation  *allocation, HTMLEmbedded *e)
 {
+	GtkWidget *parent;
+
+	parent = gtk_widget_get_parent (w);
+
 	if (e->width != allocation->width || e->height != allocation->height) {
 		if (e->width != allocation->width) {
 			html_object_change_set (HTML_OBJECT (e), HTML_CHANGE_ALL_CALC);
@@ -397,8 +407,8 @@ html_embedded_allocate (GtkWidget *w, GtkAllocation  *allocation, HTMLEmbedded *
 		}
 		e->height = allocation->height;
 
-		if (GTK_IS_HTML (w->parent))
-			html_engine_schedule_update (GTK_HTML (w->parent)->engine);
+		if (GTK_IS_HTML (parent))
+			html_engine_schedule_update (GTK_HTML (parent)->engine);
 	}
 }
 
