@@ -54,7 +54,6 @@ copy (HTMLObject *self,
 
 	(* HTML_OBJECT_CLASS (parent_class)->copy) (self,dest);
 
-
 	/* FIXME g_warning ("HTMLSelect::copy() is not complete."); */
 	d->size =    s->size;
 	d->multi =   s->multi;
@@ -103,7 +102,7 @@ add_selected (GtkTreeModel *model,
               GtkTreePath *path,
               GtkTreeIter *iter,
               struct EmbeddedSelectionInfo *info,
-              const gchar* codepage)
+              const gchar * codepage)
 {
 	gchar *value, *encoded;
 
@@ -271,7 +270,7 @@ html_select_new (GtkWidget *parent,
 }
 
 void
-html_select_add_option (HTMLSelect *select, gchar *value, gboolean selected)
+html_select_add_option (HTMLSelect *select, const gchar *value, gboolean selected)
 {
 	GtkListStore *store;
 	GtkTreeIter iter;
@@ -315,7 +314,7 @@ html_select_add_option (HTMLSelect *select, gchar *value, gboolean selected)
 }
 
 void
-html_select_set_text (HTMLSelect *select, gchar *text)
+html_select_set_text (HTMLSelect *select, const gchar *text)
 {
 	GtkWidget *w = GTK_WIDGET (HTML_EMBEDDED (select)->widget);
 	GtkListStore *store;
